import { Output, EventEmitter, AfterViewChecked } from "@angular/core";

export abstract class BaseComponent implements AfterViewChecked {
    /**
     * true après le 1er affichage du composant
     */
    private _firstViewChecked = false;

    /**
     * true si on souhaite qu'un événement soit émis en même temps que l'appel à afterFirstViewChecked()
     */
    protected emitFirstViewCheck: boolean = false;

    /**
     * événement émis en même temps que l'appel à afterFirstViewChecked()
     */
    @Output()
    private onFirstViewCheck: EventEmitter<void>;

    constructor() {
        this.onFirstViewCheck = new EventEmitter();
    }

    public ngAfterViewChecked() {
        if (!this._firstViewChecked) {
            this._firstViewChecked = true;

            this.afterFirstViewChecked();

            if (this.emitFirstViewCheck)
                this.onFirstViewCheck.emit();
        }
    }

    /**
     * appelé une fois, après l'affichage complet du composant
     */
    protected abstract afterFirstViewChecked();
}