import { Component, ViewChild, Output, EventEmitter, AfterViewChecked } from "@angular/core";

import { FixedVarResultsComponent } from "../../components/fixedvar-results/fixedvar-results.component";
import { SectionResultsComponent } from "../../components/section-results/section-results.component";
import { RemousResultsComponent } from "../../components/remous-results/remous-results.component";
import { FormulaireDefinition } from "../../formulaire/formulaire-definition";

@Component({
    selector: "calc-results",
    templateUrl: "./calculator-results.component.html",
})
export class CalculatorResultsComponent implements AfterViewChecked {
    private _formulaire: FormulaireDefinition;

    /**
     * composant d'affichage des résultats de paramètres fixés/variables
     */
    @ViewChild(FixedVarResultsComponent)
    private fixedVarResultsComponent: FixedVarResultsComponent;

    /**
     * composant d'affichage des résultats des sections paramétrées
     */
    @ViewChild(SectionResultsComponent)
    private sectionResultsComponent: SectionResultsComponent;

    /**
     * composant d'affichage des résultats des courbes de remous
     */
    @ViewChild(RemousResultsComponent)
    private remousResultsComponent: RemousResultsComponent;

    /**
     * événement émis à la fin du dessin de la vue
     */
    @Output()
    private afterViewChecked = new EventEmitter();

    public set formulaire(f: FormulaireDefinition) {
        this._formulaire = f;
        if (this._formulaire == undefined) {
            this.fixedVarResultsComponent.results = undefined;
            this.sectionResultsComponent.results = undefined;
            this.remousResultsComponent.results = undefined;
        }
        else {
            this.fixedVarResultsComponent.results = f.fixVarResults;
            this.sectionResultsComponent.results = f.sectionResults;
            this.remousResultsComponent.results = f.remousResults;
        }
    }

    public updateView() {
        this.fixedVarResultsComponent.updateView();
        this.sectionResultsComponent.updateView();
        this.remousResultsComponent.updateView();
    }

    public ngAfterViewChecked() {
        this.afterViewChecked.emit();
    }

    private getFixedVarResultsStyleDisplay() {
        return this._formulaire != undefined && this._formulaire.hasFixVarResults() ? "block" : "none";
    }

    private getSectionResultsStyleDisplay() {
        return this._formulaire != undefined && this._formulaire.hasSectionResults() ? "block" : "none";
    }

    private getRemousResultsStyleDisplay() {
        return this._formulaire != undefined && this._formulaire.hasRemousResults() ? "block" : "none";
    }
}
