import { Component, ViewChild, DoCheck } from "@angular/core";

import { InternationalisationService } from "../../services/internationalisation/internationalisation.service";
import { ApplicationSetupService } from '../../services/app-setup/app-setup.service';
import { LogComponent } from '../../components/log/log.component';
import { FixedVarResults } from "../../results/fixed-var-results";
import { ResultsGraphComponent } from "../results-graph/results-graph.component";

@Component({
    selector: "fixedvar-results",
    templateUrl: "./fixedvar-results.component.html",
    styles: [`
    .result_right {
        text-align: right;
    }
    .result_center {
        text-align: center;
    }
    .result_id_0 {
        background-color: #f0f0f0;
    }
    .result_id_1 {
        background-color: #ffffff;
    }
    .result_id_2 {
        font-weight: bolder;
        background-color: #00d0ff;
    }
    `
    ]
})
export class FixedVarResultsComponent implements DoCheck {
    /**
     * résultats non mis en forme
     */
    private _results: FixedVarResults;

    /**
     * résultats fixed mis en forme
     */
    private _fixedResults: Object[];

    /**
     * résultats fixed mis en forme
     */
    private _varResults: Object[];

    /**
     * true si le graphe des résultats doit être remis à jour
     */
    private _updateResultsGraph: boolean;

    /**
     * composant journal
     */
    @ViewChild(LogComponent)
    private logComponent: LogComponent;

    @ViewChild(ResultsGraphComponent)
    private resultsGraphComponent: ResultsGraphComponent;

    constructor(
        private intlService: InternationalisationService,
        private appSetupService: ApplicationSetupService
    ) { }

    public set results(r: FixedVarResults) {
        this._results = r;
        this._updateResultsGraph = true;
    }

    public updateView() {
        this._fixedResults = [];
        this._varResults = [];
        this.logComponent.log = undefined;
        this.generateResults();
        this._updateResultsGraph = true;
    }

    public ngDoCheck() {
        if (this._updateResultsGraph) {
            if (this.resultsGraphComponent != undefined) {
                this.resultsGraphComponent.results = this._results;
                this.resultsGraphComponent.updateView();
                this._updateResultsGraph = false;
            }
        }
    }

    private generateResults() {
        if (this._results != undefined) {
            const nDigits = this.appSetupService.displayDigits;
            const prec = this.appSetupService.displayPrecision;

            for (let r of this._results.fixedResults) {
                let v = r["value"];
                this._fixedResults.push({ "label": r["label"], "value": v.toFixed(nDigits) });
            }

            for (let r of this._results.varResults)
                this._varResults.push({ "param": r["param"].toFixed(nDigits), "result": r["result"].toFixed(nDigits) });

            this.logComponent.log = this._results.log;
        }
    }

    /**
     * affichage de la table des résultats fixés
     */
    private get showFixedResults(): boolean {
        return this._results != undefined && this._results.hasFixedResults();
    }

    /**
     * affichage de la table des résultats variés
     */
    private get showVarResults(): boolean {
        return this._results != undefined && this._results.hasVarResults();
    }

    private get uitextParamFixes() {
        return this.intlService.localizeText("INFO_CALCULATOR_PARAMFIXES");
    }

    private get uitextValeurs() {
        return this.intlService.localizeText("INFO_CALCULATOR_VALEURS");
    }

    private getFixedResultClass(i: number) {
        if (this._results.isFixed && i == this._results.fixedResults.length - 1)
            return "font-weight-bold";
        return "result_id_" + String(i & 1);
    }
}
