import { Component, Output, EventEmitter } from "@angular/core";
import { BaseComponent } from "../base/base.component";

/*
  exemple de template :

<div class="btn-group" dropdown (click)="onSelect($event)">
    <button dropdownToggle class="btn btn-primary dropdown-toggle waves-light my-1" type="button" mdbRippleRadius>
        {{currentLabel}}
    </button>
    <div class="dropdown-menu">
        <a class="dropdown-item" *ngFor="let e of entries" [value]=e>{{entryLabel(e)}}</a>
    </div>
</div>
*/

export abstract class GenericSelectComponent<T> extends BaseComponent {
    // valeur actuellement sélectionnée
    // la valeur repère une entrée de la liste (cf. [value] dans le template)
    private _selectedValue: T;

    /**
     * selected value event
     */
    @Output()
    private selectChange = new EventEmitter<T>();

    constructor() {
        super();
    }

    public get selectedValue(): T {
        return this._selectedValue;
    }

    public set selectedValue(v: T) {
        this._selectedValue = v;
    }

    private get currentLabel(): string {
        for (let e of this.entries)
            if (e == this._selectedValue)
                return this.entryLabel(e);

        return "<no selection>";
    }

    /**
     * appelé quand la valeur courante change dans l'UI
     */
    private onSelect(event: any) {
        const val = event.target.value;
        if (val != undefined) {
            this._selectedValue = val;
            this.selectedValueChanged(val);
            this.selectChange.emit(this._selectedValue);
        }
    }

    /**
     * appelé une fois, après l'affichage complet du composant
     */
    protected afterFirstViewChecked() {
        if (this.entries.length > 0)
            this._selectedValue = this.entries[0];
    }

    /**
     * appelé après que la valeur courante change
     */
    protected selectedValueChanged(val: T) {
    }

    /**
     * liste des objets sélectionnables
     */
    protected abstract get entries(): any[];

    /**
     * calcule l'étiquette d'une entrée (ce qui est affiché dans la liste déroulante)
     */
    protected abstract entryLabel(entry: any): string;
}
