import { Component } from "@angular/core";

import { Message, cLog } from 'jalhyd';

import { NgParameter } from "../../formulaire/ngparam";
import { InternationalisationService } from "../../services/internationalisation/internationalisation.service";
import { ApplicationSetupService } from '../../services/app-setup/app-setup.service';


@Component({
    selector: "log",
    templateUrl: "./log.component.html",
    styles: [`
        .hyd_log {
            border : 1px solid black;
            margin : 1.8em 0;
            padding-top : 1.3em;
            border-radius: 10px;
        }
        .titre {
            background-color: #00b0ff;
            border: 1px solid black;
            border-radius: 5px;
            float: left;
            font-size: 1.15em;
            font-weight: bold;
            margin-bottom: -1em;
            margin-left: 0.5em;
            margin-top: -2.3em;
            padding: 0.2em 0.5em;
        }
    `]
})
export class LogComponent {
    /**
     * journal
     */
    private _log: cLog;

    /**
    * entrées du journal mises en forme
    */
    private _logEntries: string[];

    constructor(
        private intlService: InternationalisationService,
        private appSetupService: ApplicationSetupService
    ) { }

    private get uitextTitreJournal() {
        return this.intlService.localizeText("INFO_REMOUSRESULTS_TITREJOURNAL")
    }

    private get hasEntries(): boolean {
        return this._logEntries != undefined && this._logEntries.length != 0;
    }

    private generateEntries() {
        this._logEntries = [];
        if (this._log != undefined) {
            const nDigits = this.appSetupService.displayDigits;
            for (let m of this._log.messages)
                this._logEntries.push(this.intlService.localizeMessage(m, nDigits));
        }
    }

    public set log(log: cLog) {
        this._log = log;
        this.generateEntries();
    }
}
