import { Component, AfterViewInit, EventEmitter, Output, ViewChild } from '@angular/core';

import { FixedVarResults, GraphType } from "../../results/fixed-var-results";
import { GraphTypeSelectComponent } from './graph-type.component';

@Component({
    selector: 'results-graph',
    templateUrl: './results-graph.component.html'
})
export class ResultsGraphComponent {
    private _results: FixedVarResults;

    @ViewChild(GraphTypeSelectComponent)
    private _graphTypeComponent: GraphTypeSelectComponent;

    /*
     * config du graphe
     */
    private graph_type: string;
    private graph_data = {};
    private graph_options = {
        responsive: true,
        maintainAspectRatio: true,
        animation: {
            duration: 0
        },
        legend: {
            display: false
        },
        title: {
            display: true,
            text: ""
        }
    };

    public set results(r: FixedVarResults) {
        this._results = r;
        this._graphTypeComponent.selectedValue = r.graphType;
    }

    public updateView() {
        switch (this._graphTypeComponent.selectedValue) {
            case GraphType.Histogram:
                this.graph_type = "bar";
                this.generateBarGraph();
                break;

            case GraphType.HistoLine:
                this.graph_type = "line";
                this.generateLineGraph();
                break;

            default:
                this.graph_type = "scatter";
                this.generateScatterGraph();
                break;
        }
    }

    private onGraphTypeSelectChange(event) {
        this.updateView();
    }

    /**
     * génère les données d'un graphe de type "line"
     */
    private generateLineGraph() {
        let labs = [];
        let dat = [];
        for (let i in this._results.varResults) {
            let r = this._results.varResults[i];
            labs.push(r["param"]);
            dat.push(this._results.varGraph[i]);
        }

        this.graph_options.title.text = this._results.graphTitle;

        this.graph_data = {
            labels: labs,
            datasets: [
                {
                    label: "",
                    data: dat
                }
            ]
        };
    }

    /**
     * génère les données d'un graphe de type "bar"
     */
    private generateBarGraph() {
        let labs = [];
        let dat = [];
        for (let i in this._results.varResults) {
            let r = this._results.varResults[i];
            labs.push(r["param"]);
            dat.push(this._results.varGraph[i]);
        }

        this.graph_options.title.text = this._results.graphTitle;
        this.graph_options["scales"] = {
            xAxes: [{
                gridLines: {
                    offsetGridLines: true
                }
            }]
        };

        this.graph_data = {
            labels: labs,
            datasets: [
                {
                    label: "",
                    data: dat
                }
            ]
        };
    }

    /**
     * génère les données d'un graphe de type "scatter"
     */
    private generateScatterGraph() {
        let dat = [];
        for (let i in this._results.varResults) {
            let r = this._results.varResults[i];
            dat.push({ x: r["param"], y: this._results.varGraph[i] });
        }

        this.graph_options.title.text = this._results.graphTitle;
        this.graph_options["scales"] = {
            xAxes: [{
                type: 'linear',
                position: 'bottom'
            }],
            yAxes: [{
                type: 'linear',
                position: 'left'
            }]
        };

        this.graph_data = {
            datasets: [
                {
                    label: "",
                    data: dat,
                    borderColor: "#808080", // couleur de la ligne
                    backgroundColor: "rgba(0,0,0,0)",  // couleur de remplissage sous la courbe : transparent
                    showLine: "true"
                }
            ]
        };
    }
}
