import { Component, ViewChild } from '@angular/core';

import { acSection } from 'jalhyd';

import { SectionCanvasComponent } from '../section-canvas/section-canvas.component';
import { SectionResults } from '../../results/section-results';
import { ApplicationSetupService } from '../../services/app-setup/app-setup.service';

@Component({
    selector: 'section-results',
    templateUrl: './section-results.component.html',
    styles: [`
    .result_label {
        text-align: right;
        padding-top:10px;
        padding-bottom:10px;
        padding-right:10px;   
    }
    .result_value {
        text-align: center;
        padding-left:30px;   
        padding-right:30px;   
    }
    .result_id_0 {
        background-color: #f0f0f0;
    }
    .result_id_2 {
        font-weight: bold;
    }
    `
    ]
})
export class SectionResultsComponent {
    /**
    * résultats non mis en forme
    */
    private _sectionResults: SectionResults;

    /**
     * résultats mis en forme
     */
    private _results: Object[];

    constructor(private appSetupService: ApplicationSetupService) { }

    private static labelColors: { [key: string]: any; } = {
        "Hs": { r: 255, g: 0, b: 0 },
        "Hsc": { r: 0, g: 0, b: 255 },
        "Yn": { r: 16, g: 128, b: 16 },
        "Yf": { r: 128, g: 128, b: 128 },
        "Yt": { r: 0, g: 0, b: 0 },
        "Yc": { r: 255, g: 128, b: 0 },
        "Yco": { r: 255, g: 0, b: 255 },
    };

    @ViewChild(SectionCanvasComponent)
    private _sectionCanvas: SectionCanvasComponent;

    public set results(r: SectionResults) {
        this._sectionResults = r;
        this.updateView();
    }

    public updateView() {
        this._results = [];
        this._sectionCanvas.reset();
        if (this._sectionResults != undefined)
            this.formatResults();
    }

    private formatResults() {
        if (this._sectionResults.results.length > 0) {
            const nDigits = this.appSetupService.displayDigits;

            for (let r of this._sectionResults.results) {
                const v = r["value"];
                const l = r["label"];

                this._results.push({ "label": l, "value": v.toFixed(nDigits) });

                const drawLabel = r["drawLabel"];
                if (drawLabel != undefined)
                    this._sectionCanvas.addLevel(v, drawLabel + " = " + v.toFixed(nDigits), SectionResultsComponent.labelColors[drawLabel]);
            }
            this._sectionCanvas.section = this._sectionResults.section;
        }
    }

    private getResultClass(i: number) {
        return "result_id_" + String(i & 1);
    }
}
